==> symengine-0.6.1.tar.gz: symengine-0.6.1/symengine/cmake_install.cmake <==
# Install script for directory: /home/isuru/projects/symengine.py/symengine

# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
  set(CMAKE_INSTALL_PREFIX "/usr/local")
endif()
string(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
if(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  if(BUILD_TYPE)
    string(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  else()
    set(CMAKE_INSTALL_CONFIG_NAME "Release")
  endif()
  message(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
endif()

# Set the component getting installed.
if(NOT CMAKE_INSTALL_COMPONENT)
  if(COMPONENT)
    message(STATUS "Install component: \"${COMPONENT}\"")
    set(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  else()
    set(CMAKE_INSTALL_COMPONENT)
  endif()
endif()

# Install shared libraries without execute permission?
if(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  set(CMAKE_INSTALL_SO_NO_EXE "1")
endif()

# Is this installation the result of a crosscompile?
if(NOT DEFINED CMAKE_CROSSCOMPILING)
  set(CMAKE_CROSSCOMPILING "FALSE")
endif()

if("x${CMAKE_INSTALL_COMPONENT}x" STREQUAL "xUnspecifiedx" OR NOT CMAKE_INSTALL_COMPONENT)
  list(APPEND CMAKE_ABSOLUTE_DESTINATION_FILES
   "/home/isuru/miniconda3/lib/python3.7/site-packages/symengine/__init__.py;/home/isuru/miniconda3/lib/python3.7/site-packages/symengine/utilities.py;/home/isuru/miniconda3/lib/python3.7/site-packages/symengine/compatibility.py;/home/isuru/miniconda3/lib/python3.7/site-packages/symengine/sympy_compat.py;/home/isuru/miniconda3/lib/python3.7/site-packages/symengine/functions.py;/home/isuru/miniconda3/lib/python3.7/site-packages/symengine/printing.py")
  if(CMAKE_WARN_ON_ABSOLUTE_INSTALL_DESTINATION)
    message(WARNING "ABSOLUTE path INSTALL DESTINATION : ${CMAKE_ABSOLUTE_DESTINATION_FILES}")
  endif()
  if(CMAKE_ERROR_ON_ABSOLUTE_INSTALL_DESTINATION)
    message(FATAL_ERROR "ABSOLUTE path INSTALL DESTINATION forbidden (by caller): ${CMAKE_ABSOLUTE_DESTINATION_FILES}")
  endif()
file(INSTALL DESTINATION "/home/isuru/miniconda3/lib/python3.7/site-packages/symengine" TYPE FILE FILES
    "/home/isuru/projects/symengine.py/symengine/__init__.py"
    "/home/isuru/projects/symengine.py/symengine/utilities.py"
    "/home/isuru/projects/symengine.py/symengine/compatibility.py"
    "/home/isuru/projects/symengine.py/symengine/sympy_compat.py"
    "/home/isuru/projects/symengine.py/symengine/functions.py"
    "/home/isuru/projects/symengine.py/symengine/printing.py"
    )
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for each subdirectory.
  include("/home/isuru/projects/symengine.py/symengine/lib/cmake_install.cmake")
  include("/home/isuru/projects/symengine.py/symengine/tests/cmake_install.cmake")

endif()

==> symengine-0.14.1.tar.gz: symengine-0.14.1/symengine/cmake_install.cmake <==
# Install script for directory: /home/isuru/projects/symengine.py/symengine

# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
  set(CMAKE_INSTALL_PREFIX "/usr/local")
endif()
string(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
if(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  if(BUILD_TYPE)
    string(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  else()
    set(CMAKE_INSTALL_CONFIG_NAME "Release")
  endif()
  message(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
endif()

# Set the component getting installed.
if(NOT CMAKE_INSTALL_COMPONENT)
  if(COMPONENT)
    message(STATUS "Install component: \"${COMPONENT}\"")
    set(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  else()
    set(CMAKE_INSTALL_COMPONENT)
  endif()
endif()

# Install shared libraries without execute permission?
if(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  set(CMAKE_INSTALL_SO_NO_EXE "1")
endif()

# Is this installation the result of a crosscompile?
if(NOT DEFINED CMAKE_CROSSCOMPILING)
  set(CMAKE_CROSSCOMPILING "FALSE")
endif()

# Set path to fallback-tool for dependency-resolution.
if(NOT DEFINED CMAKE_OBJDUMP)
  set(CMAKE_OBJDUMP "/home/isuru/miniforge3/bin/objdump")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/home/isuru/projects/symengine.py/symengine/lib/cmake_install.cmake")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/home/isuru/projects/symengine.py/symengine/tests/cmake_install.cmake")
endif()

if(CMAKE_INSTALL_COMPONENT STREQUAL "Unspecified" OR NOT CMAKE_INSTALL_COMPONENT)
  list(APPEND CMAKE_ABSOLUTE_DESTINATION_FILES
   "/home/isuru/miniforge3/lib/python3.13/site-packages/symengine/__init__.py;/home/isuru/miniforge3/lib/python3.13/site-packages/symengine/functions.py;/home/isuru/miniforge3/lib/python3.13/site-packages/symengine/printing.py;/home/isuru/miniforge3/lib/python3.13/site-packages/symengine/sympy_compat.py;/home/isuru/miniforge3/lib/python3.13/site-packages/symengine/test_utilities.py;/home/isuru/miniforge3/lib/python3.13/site-packages/symengine/utilities.py")
  if(CMAKE_WARN_ON_ABSOLUTE_INSTALL_DESTINATION)
    message(WARNING "ABSOLUTE path INSTALL DESTINATION : ${CMAKE_ABSOLUTE_DESTINATION_FILES}")
  endif()
  if(CMAKE_ERROR_ON_ABSOLUTE_INSTALL_DESTINATION)
    message(FATAL_ERROR "ABSOLUTE path INSTALL DESTINATION forbidden (by caller): ${CMAKE_ABSOLUTE_DESTINATION_FILES}")
  endif()
  file(INSTALL DESTINATION "/home/isuru/miniforge3/lib/python3.13/site-packages/symengine" TYPE FILE FILES
    "/home/isuru/projects/symengine.py/symengine/__init__.py"
    "/home/isuru/projects/symengine.py/symengine/functions.py"
    "/home/isuru/projects/symengine.py/symengine/printing.py"
    "/home/isuru/projects/symengine.py/symengine/sympy_compat.py"
    "/home/isuru/projects/symengine.py/symengine/test_utilities.py"
    "/home/isuru/projects/symengine.py/symengine/utilities.py"
    )
endif()

string(REPLACE ";" "\n" CMAKE_INSTALL_MANIFEST_CONTENT
       "${CMAKE_INSTALL_MANIFEST_FILES}")
if(CMAKE_INSTALL_LOCAL_ONLY)
  file(WRITE "/home/isuru/projects/symengine.py/symengine/install_local_manifest.txt"
     "${CMAKE_INSTALL_MANIFEST_CONTENT}")
endif()
